@@ -2,7 +2,10 @@
 """
 
 
+# pylint: disable=too-few-public-methods
 class Configuration:
+    """Configuration inside class to be used as an abstract class
+    """
     # The version number of the transformer
     TRANSFORMER_VERSION = None
 
