@@ -6,16 +6,14 @@ import argparse
 import json
 import logging
 import os
-import sys
 from typing import Optional
-
-from importlib import import_module
 import yaml
 
-from transformer_class import TransformerClass
-from configuration import Configuration
+from agpypeline.transformer_class import TransformerClass
+from agpypeline.configuration import Configuration
 
-class __internal__():
+
+class __internal__:
     """Class for functions intended for internal use only for this file
     """
 
@@ -218,6 +216,7 @@ class __internal__():
         """
         result = {}
 
+        # pylint: disable=no-member
         if hasattr(transformer_instance, 'check_continue'):
             check_result = TransformerClass.check_continue(transformer_instance, **transformer_params)
             result_code, result_message = __internal__.parse_continue_result(check_result)
@@ -295,6 +294,7 @@ class __internal__():
             result = __internal__.handle_retrieve_files(transformer_instance, args, metadata)
 
         # Next make the call to perform the processing
+        # pylint: disable=no-member
         if 'error' not in result:
             if hasattr(TransformerClass, 'perform_process'):
                 result = TransformerClass.perform_process(transformer_instance, **transformer_params)
@@ -360,6 +360,7 @@ def add_parameters(parser: argparse.ArgumentParser, transformer_instance) -> Non
         transformer_instance.add_parameters(parser)
 
     # Check if the transformer has a function defined to extend command line arguments
+    # pylint: disable=no-value-for-parameter
     if hasattr(TransformerClass, 'add_parameters'):
         TransformerClass.add_parameters(parser)
 
