@@ -11,7 +11,8 @@ class Transformer:
         """Initializes a class instance
         """
 
-    def perform_process(self, transformer: transformer_class.Transformer, check_md: dict, transformer_md: dict,
+    # pylint: disable=no-self-use
+    def perform_process(self, transformer: transformer_class.TransformerClass, check_md: dict, transformer_md: dict,
                         full_md: dict) -> dict:
         """Perform the processing of data
         Arguments:
@@ -21,4 +22,4 @@ class Transformer:
             full_md: dictionary
         """
         # pylint: disable=unused-argument
-        return {}
\ No newline at end of file
+        return {}
