@@ -4,17 +4,13 @@
 import argparse
 import datetime
 import logging
-import os
-import sys
-
-from importlib import import_module
 import piexif
 
 
 from numpy import nan
 from osgeo import gdal, osr
 
-from configuration import Configuration
+from agpypeline.configuration import Configuration
 
 # EXIF tags to look for
 EXIF_ORIGIN_TIMESTAMP = 36867  # Capture timestamp
@@ -22,7 +18,7 @@ EXIF_TIMESTAMP_OFFSET = 36881  # Timestamp UTC offset (general)
 EXIF_ORIGIN_TIMESTAMP_OFFSET = 36881  # Capture timestamp UTC offset
 
 
-class __internal__():
+class __internal__:
     """Class containing functions for this file only
     """
 
